@@ -2,7 +2,7 @@ package VIC::Grammar;
 use strict;
 use warnings;
 
-our $VERSION = '0.24';
+our $VERSION = '0.25';
 $VERSION = eval $VERSION;
 
 use Pegex::Base;
@@ -14,7 +14,7 @@ sub make_tree {   # Generated/Inlined by Pegex::Grammar (0.60)
   {
     '+grammar' => 'vic',
     '+toprule' => 'program',
-    '+version' => '0.2.5',
+    '+version' => '0.2.7',
     'COMMA' => {
       '.rgx' => qr/\G,/
     },
@@ -232,7 +232,7 @@ sub make_tree {   # Generated/Inlined by Pegex::Grammar (0.60)
     'assign_operator' => {
       '.any' => [
         {
-          '.rgx' => qr/\G([\+\-%\^\*\|&\/]?=)/
+          '.rgx' => qr/\G([\+\-%\^\*\|&\/\.]?=)/
         },
         {
           '.ref' => 'shift_assign_operator'
@@ -413,9 +413,6 @@ sub make_tree {   # Generated/Inlined by Pegex::Grammar (0.60)
             },
             {
               '.ref' => 'modifier_constant'
-            },
-            {
-              '.ref' => 'parameter'
             }
           ]
         }
@@ -440,6 +437,9 @@ sub make_tree {   # Generated/Inlined by Pegex::Grammar (0.60)
         },
         {
           '.any' => [
+            {
+              '.ref' => 'parameter'
+            },
             {
               '.ref' => 'number'
             },
