@@ -3,7 +3,7 @@ use strict;
 use warnings;
 use Carp;
 
-our $VERSION = '0.24';
+our $VERSION = '0.25';
 $VERSION = eval $VERSION;
 
 use VIC::PIC::Gpsim;
@@ -75,8 +75,10 @@ sub new_simulator {
     my $stype = 'Gpsim';
     if (exists $hh{type}) {
         $stype = SIMS->{lc $hh{type}};
-        carp "No simulator of type $hh{type}\n" unless $stype;
-        return;
+        unless (defined $stype) {
+            carp "No simulator of type $hh{type}";
+            return;
+        }
     }
     $class =~ s/::Any/::$stype/g;
     $hh{type} = lc $stype;
