@@ -1,7 +1,7 @@
 package VIC::PIC::Functions::CodeGen;
 use strict;
 use warnings;
-our $VERSION = '0.24';
+our $VERSION = '0.25';
 $VERSION = eval $VERSION;
 use Carp;
 use POSIX ();
@@ -24,6 +24,9 @@ has code_config => (is => 'rw', default => sub {
                 bits => 8, # bits. same as register_size
                 export => 0, # do not export variables
             },
+            string => {
+                size => 32, # character allocation of null strings
+            },
             uart => {
                 baud => 9600, # baud rate
                 bit9 => 0, # allow 9 bits
@@ -42,6 +45,8 @@ sub validate {
     return 0 unless $self->doesrole('Chip');
     return 1 if exists $self->pins->{$var};
     return 1 if exists $self->registers->{$var};
+    return 1 if ($self->doesrole('Timer', 1) and exists $self->timer_pins->{$var});
+    return 1 if ($self->doesrole('Timer', 1) and exists $self->wdt_prescaler->{$var});
     return 1 if ($self->doesrole('USART', 1) and exists $self->usart_pins->{$var});
     return 0;
 }
