@@ -1,7 +1,7 @@
 package VIC::PIC::Functions::ISR;
 use strict;
 use warnings;
-our $VERSION = '0.24';
+our $VERSION = '0.25';
 $VERSION = eval $VERSION;
 use Carp;
 use POSIX ();
@@ -10,7 +10,11 @@ use Moo::Role;
 sub isr_var {
     my $self = shift;
     return unless $self->doesroles(qw(Chip ISR));
-    my ($cb_start, $cb_end) = @{$self->banks->{common}};
+    my @common = @{$self->banks->{common}};
+    my ($cb_start, $cb_end) = @common;
+    if (ref $cb_start eq 'ARRAY') {
+        ($cb_start, $cb_end) = @$cb_start;
+    }
     $cb_start = 0x70 unless $cb_start;
     $cb_start = sprintf "0x%02X", $cb_start;
     return << "...";
@@ -25,7 +29,7 @@ sub isr_entry {
     my $self = shift;
     return unless $self->doesroles(qw(Chip ISR));
     unless (exists $self->registers->{STATUS}) {
-        carp $self->pic->type, " has no register named STATUS";
+        carp $self->type, " has no register named STATUS";
         return;
     }
     #TODO: high/low address ?
@@ -51,7 +55,7 @@ sub isr_exit {
     my $self = shift;
     return unless $self->doesroles(qw(Chip ISR));
     unless (exists $self->registers->{STATUS}) {
-        carp $self->pic->type, " has no register named STATUS";
+        carp $self->type, " has no register named STATUS";
         return;
     }
     return << "...";
@@ -72,7 +76,7 @@ sub isr_timer {
     my $freg = $th->{freg};
     my $ereg = $th->{ereg};
     unless (exists $self->registers->{$freg} and exists $self->registers->{$ereg}) {
-        carp $self->pic->type, " has no register named $freg or $ereg";
+        carp $self->type, " has no register named $freg or $ereg";
         return;
     }
     my $tflag = $th->{flag};
@@ -123,14 +127,14 @@ sub isr_ioc {
     my $self = shift;
     return unless $self->doesroles(qw(Chip ISR));
     unless (exists $self->registers->{INTCON}) {
-        carp $self->pic->type, " has no register named INTCON";
+        carp $self->type, " has no register named INTCON";
         return;
     }
     my $ioch = shift;
     my $ipin = shift;
     return unless (defined $ioch and ref $ioch eq 'HASH');
+    return unless defined $ipin;
     my $ioc_reg = $ioch->{reg};
-    return unless (defined $ioc_reg and defined $ipin);
     my $ioc_bit = $ioch->{bit};
     my $ioc_flag = $ioch->{flag};
     my $ioc_enable = $ioch->{enable};
@@ -140,7 +144,14 @@ sub isr_ioc {
         my $end_label = $isr{END};
         return unless $action_label;
         return unless $end_label;
-        my $isr_label = '_isr_' . ((defined $ioc_bit) ? lc($ioc_bit) : lc($ioc_reg));
+        my $isr_label;
+        if (defined $ioc_bit) {
+            $isr_label = '_isr_' . lc($ioc_bit);
+        } elsif (defined $ioc_reg) {
+            $isr_label = '_isr_' .lc($ioc_reg);
+        } else {
+            $isr_label = '_isr_' . lc($ipin);
+        }
         my $code_ioc = '';
         if (defined $portbit) {
             $code_ioc = "\tbtfsc $port, $portbit\n\taddlw 0x01";
@@ -162,10 +173,12 @@ $end_label:
 
     } else {
         my $code_en = '';
-        if (defined $ioc_bit) {
-            $code_en = "\tbsf $ioc_reg, $ioc_bit";
+        if (defined $ioc_bit and defined $ioc_reg) {
+            $code_en = "\tbanksel $ioc_reg\n\tbsf $ioc_reg, $ioc_bit";
+        } elsif (defined $ioc_reg) {
+            $code_en = "\tbanksel $ioc_reg\n\tclrf $ioc_reg\n\tcomf $ioc_reg, F";
         } else {
-            $code_en = "\tclrf $ioc_reg\n\tcomf $ioc_reg, F";
+            # if ioc_reg/ioc_bit is not defined just move on
         }
         return << "...";
 ;; enable interrupt-on-change setup for $ipin
@@ -173,7 +186,6 @@ $end_label:
 \tbcf INTCON, $ioc_flag
 \tbsf INTCON, GIE
 \tbsf INTCON, $ioc_enable
-\tbanksel $ioc_reg
 $code_en
 ;; end of interrupt-on-change setup
 ...
