@@ -2,7 +2,7 @@ package VIC::PIC::Functions::Operations;
 use strict;
 use warnings;
 use bigint;
-our $VERSION = '0.24';
+our $VERSION = '0.25';
 $VERSION = eval $VERSION;
 use Carp;
 use POSIX ();
@@ -311,7 +311,7 @@ sub debounce {
     my ($self, $inp, %action) = @_;
     return unless $self->doesroles(qw(Operations Chip CodeGen GPIO));
     unless (exists $self->registers->{STATUS}) {
-        carp $self->pic->type, " does not have the STATUS register";
+        carp $self->type, " does not have the STATUS register";
         return;
     }
     my $action_label = $action{ACTION};
