@@ -2,7 +2,7 @@ package VIC::PIC::Functions::Operators;
 use strict;
 use warnings;
 use bigint;
-our $VERSION = '0.24';
+our $VERSION = '0.25';
 $VERSION = eval $VERSION;
 use Carp;
 use POSIX ();
@@ -11,6 +11,11 @@ use Moo::Role;
 sub _assign_literal {
     my ($self, $var, $val) = @_;
     return unless $self->doesrole('Chip'); # needed for address_bits
+    if (ref $var eq 'HASH' and $var->{type} eq 'string') {
+        #YYY { lhs => $var, rhs => $var };
+        carp $var->{name}, " has been defined as a string and '$val' is not a string !";
+        return;
+    }
     my $bits = $self->address_bits($var);
     my $bytes = POSIX::ceil($bits / 8);
     my $nibbles = 2 * $bytes;
@@ -29,6 +34,7 @@ sub _assign_literal {
         }
     } else {
         my $valbyte = $val & ((2 ** 8) - 1);
+        $code .= "\tbanksel $var\n";
         $code .= sprintf "\tmovlw 0x%02X\n\tmovwf $var\n", $valbyte if $valbyte > 0;
         $code .= "\tclrf $var\n" if $valbyte == 0;
         for (2 .. $bytes) {
@@ -44,16 +50,130 @@ sub _assign_literal {
     return $code;
 }
 
+sub _op_assign_str_var {
+    return <<"....";
+;;;; for m_op_assign_str/m_op_nullify_str/m_op_concat_byte
+VIC_VAR_ASSIGN_STRIDX res 1
+VIC_VAR_ASSIGN_STRLEN res 1
+....
+}
+
+sub _op_nullify_str {
+    return << "...";
+m_op_nullify_str macro dvar, dlen, didx
+\tlocal _op_nullify_str_loop_0
+\tlocal _op_nullify_str_loop_1
+\tbanksel VIC_VAR_ASSIGN_STRLEN
+\tmovlw dlen
+\tmovwf VIC_VAR_ASSIGN_STRLEN
+\tbanksel dvar
+\tmovlw (dvar - 1)
+\tmovwf FSR
+\tbanksel VIC_VAR_ASSIGN_STRIDX
+\tclrf VIC_VAR_ASSIGN_STRIDX
+_op_nullify_str_loop_0:
+\tclrw
+\tincf FSR, F
+\tmovwf INDF
+\tbanksel VIC_VAR_ASSIGN_STRIDX
+\tincf VIC_VAR_ASSIGN_STRIDX, F
+\tbcf STATUS, Z
+\tbcf STATUS, C
+\tmovf VIC_VAR_ASSIGN_STRIDX, W
+\tsubwf VIC_VAR_ASSIGN_STRLEN, W
+\t;; W == 0
+\tbtfsc STATUS, Z
+\tgoto _op_nullify_str_loop_1
+\tgoto _op_nullify_str_loop_0
+_op_nullify_str_loop_1:
+\tbanksel didx
+\tclrf didx
+\tendm
+...
+}
+
+sub _op_assign_str {
+    return <<"...";
+m_op_assign_str macro dvar, dlen, cvar, clen
+\tlocal _op_assign_str_loop_0
+\tlocal _op_assign_str_loop_1
+\tbanksel VIC_VAR_ASSIGN_STRLEN
+if dlen > clen
+\tmovlw clen
+else
+\tmovlw dlen
+endif
+\tmovwf VIC_VAR_ASSIGN_STRLEN
+\tbanksel dvar
+\tmovlw (dvar - 1)
+\tmovwf FSR
+\tbanksel VIC_VAR_ASSIGN_STRIDX
+\tclrf VIC_VAR_ASSIGN_STRIDX
+_op_assign_str_loop_0:
+\tmovf VIC_VAR_ASSIGN_STRIDX, W
+\tcall cvar
+\tincf FSR, F
+\tmovwf INDF
+\tbanksel VIC_VAR_ASSIGN_STRIDX
+\tincf VIC_VAR_ASSIGN_STRIDX, F
+\tbcf STATUS, Z
+\tbcf STATUS, C
+\tmovf VIC_VAR_ASSIGN_STRIDX, W
+\tsubwf VIC_VAR_ASSIGN_STRLEN, W
+\t;; W == 0
+\tbtfsc STATUS, Z
+\tgoto _op_assign_str_loop_1
+\tgoto _op_assign_str_loop_0
+_op_assign_str_loop_1:
+\tnop
+\tendm
+...
+}
+
+sub _get_idx_var {
+    my ($self, $var) = @_;
+    return uc ($var . '_IDX');
+}
+
 sub op_assign {
     my ($self, $var1, $var2, %extra) = @_;
     return unless $self->doesrole('Operators');
     my $literal = qr/^\d+$/;
     return $self->_assign_literal($var1, $var2) if $var2 =~ $literal;
+    my $code = '';
+    if (ref $var1 eq 'HASH') {
+        if ($var1->{type} eq 'string') {
+            if (ref $var2 eq 'HASH' && exists $var2->{string}) {
+                # allocate the constant string into the variable location
+                my $cvar = $var2->{name};# constant var location
+                my $clen = sprintf "0x%02X", $var2->{size};# constant length definition
+                my $dlen = $var1->{size};# destination length definition
+                my $dvar = $var1->{name};
+                my $macros = {};
+                $macros->{m_op_assign_str} = $self->_op_assign_str;
+                $macros->{m_op_assign_var} = $self->_op_assign_str_var;
+                $macros->{m_op_nullify_str} = $self->_op_nullify_str;
+                unless ($var2->{empty}) {
+                    $code .= "\t;;;; moving contents of $cvar into $dvar with bounds checking\n";
+                    $code .= "\tm_op_assign_str $dvar, $dlen, $cvar, $clen\n";
+                } else {
+                    $code .= "\t;;;; storing an empty string in $dvar\n";
+                    my $idxvar = $self->_get_idx_var($dvar);
+                    $code .= "\tm_op_nullify_str $dvar, $dlen, $idxvar\n";
+                }
+                return wantarray ? ($code, {}, $macros, []) : $code;
+            } else {
+                #YYY { lhs => $var1, rhs => $var2 };
+                carp $var1->{name}, " has been defined as a string and '$var2' is not a string !";
+                return;
+            }
+        }
+    }
     my $b1 = POSIX::ceil($self->address_bits($var1) / 8);
     my $b2 = POSIX::ceil($self->address_bits($var2) / 8);
     $var2 = uc $var2;
     $var1 = uc $var1;
-    my $code = "\t;; moving $var2 to $var1\n";
+    $code = "\t;; moving $var2 to $var1\n";
     if ($b1 == $b2) {
         $code .= "\tmovf $var2, W\n\tmovwf $var1\n";
         for (2 .. $b1) {
@@ -1508,12 +1628,35 @@ sub break { return 'BREAK'; }
 sub continue { return 'CONTINUE'; }
 
 sub store_string {
-    my ($self, $str, $strvar, $len, $lenvar) = @_;
-    $len = sprintf "0x%02X", $len;
-    return << "...";
-$strvar data "$str" ; $strvar is a string
-$lenvar equ $len ; $lenvar is length of $strvar
+    my ($self, $str, $strvar, $lenvar) = @_;
+    my $nstr = $str;
+    $nstr = $str->{string} if ref $str eq 'HASH';
+    my $label = $strvar;
+    $label = $str->{name} if ref $str eq 'HASH';
+    my ($code, $szdecl) = ('', '');
+    if ($str->{empty}) {
+        $code = "\t;; not storing an empty string\n";
+        my $sz = $self->code_config->{string}->{size};
+        my $len = sprintf "0x%02X", $sz;
+        my $idxvar = $self->_get_idx_var($strvar);
+        $szdecl = << "...";
+$strvar res $len; allocate memory for $strvar
+$idxvar res 1; index for accessing $strvar elements
+$lenvar equ $len; $lenvar is length of $strvar
 ...
+    } else {
+        my @bytearr = split //, $nstr;
+        my $bytes = [(map { sprintf "0x%02X", ord($_) } @bytearr), "0x00"];
+        my $len = sprintf "0x%02X", scalar(@$bytes) + 1;
+        my $slen = sprintf "0x%02X", scalar(@$bytes);
+        my $nstr2 = $nstr;
+        $nstr2 =~ s/[\n]/\\n/gs;
+        $nstr2 =~ s/[\r]/\\r/gs;
+        $code = "\t;; storing string '$nstr2'\n";
+        $code .= "$label:\n\taddwf PCL, F\n\tdt " . join(',', @$bytes) . "\n";
+        $szdecl = "$strvar res $len; allocate memory for $strvar\n$lenvar equ $slen; $lenvar is length of $label\n";
+    }
+    return wantarray ? ($code, $szdecl) : $code;
 }
 
 sub store_array {
@@ -1523,6 +1666,7 @@ sub store_array {
     my $arrstr = join (",", @$arr) if scalar @$arr;
     $arrstr = '0' unless $arrstr;
     $sz = sprintf "0x%02X", $sz;
+    ### FIXME: this is not correct. you need to do like the string stuff
     return << "..."
 $arrvar db $arr ; array stored as accessible bytes
 $szvar equ $sz   ; length of array $arrvar is a constant
@@ -1533,7 +1677,7 @@ sub store_table {
     my ($self, $table, $label, $tblsz, $tblszvar) = @_;
     return unless $self->doesrole('Chip');
     unless (exists $self->registers->{PCL}) {
-        carp $self->pic->type, " does not have the PCL register";
+        carp $self->type, " does not have the PCL register";
         return;
     }
     my $code = "$label:\n";
@@ -1602,6 +1746,76 @@ sub store_bytes {
     return $code;
 }
 
+sub string_concat {
+    return ";;;; string concatenation not implemented";
+}
+
+sub _op_concat_bytev {
+    return << "...";
+m_op_concat_bytev macro dvar, dlen, didx, bvar
+\tlocal _op_concat_bytev_end
+\t;;;; check for space first and then add byte
+\tbanksel didx
+\tmovf didx, W
+\tbanksel VIC_VAR_ASSIGN_STRIDX
+\tmovwf VIC_VAR_ASSIGN_STRIDX
+\tmovlw dlen
+\tmovwf VIC_VAR_ASSIGN_STRLEN
+\tbcf STATUS, Z
+\tbcf STATUS, C
+\tmovf VIC_VAR_ASSIGN_STRIDX, W
+\tsubwf VIC_VAR_ASSIGN_STRLEN, W
+\t;; W == 0
+\tbtfsc STATUS, Z
+\tgoto _op_concat_bytev_end
+\t;; we have space, let's add byte
+\tbanksel dvar
+\tmovlw dvar
+\tmovwf FSR
+\tbanksel didx
+\tmovf didx, W
+\taddwf FSR, F
+\tbanksel bvar
+\tmovf bvar, W
+\tmovwf INDF
+\tbanksel didx
+\tincf didx, F
+_op_concat_bytev_end:
+\tnop ;; no space left
+\tendm
+...
+}
+
+sub byte_concat {
+    my $self = shift;
+    my $dvar = shift;
+    my $svar = shift;
+    $svar = uc $svar;
+    my ($code, $funcs, $macros) = ('', {}, {});
+    if (ref $dvar eq 'HASH' and $dvar->{type} eq 'string') {
+        my $dname = $dvar->{name};
+        my $idxvar = $self->_get_idx_var($dname);
+        my $dlen = $dvar->{size};
+        $macros->{m_op_assign_var} = $self->_op_assign_str_var;
+        $macros->{m_op_concat_bytev} = $self->_op_concat_bytev($dname, $dlen, $idxvar, $svar);
+        $code = "\tm_op_concat_bytev $dname, $dlen, $idxvar, $svar\n";
+    } else {
+        carp $dvar->{name} . " is not a string. Concatenation not valid\n";
+        return;
+    }
+    return wantarray ? ($code, $funcs, $macros) : $code;
+}
+
+sub op_cat_assign {
+    my $self = shift;
+    my ($var1, $var2) = @_;
+    if (ref $var2 eq 'HASH') {
+        return $self->string_concat(@_);
+    } else {
+        return $self->byte_concat(@_);
+    }
+}
+
 1;
 __END__
 
