@@ -1,7 +1,7 @@
 package VIC::PIC::P16F627A;
 use strict;
 use warnings;
-our $VERSION = '0.24';
+our $VERSION = '0.25';
 $VERSION = eval $VERSION;
 use Carp;
 use Moo;
@@ -234,9 +234,9 @@ has wdt_prescaler => (is => 'ro', default => sub {
 
 has timer_pins => (is => 'ro', default => sub {
     {
-        TMR0 => 'TMR0',
-        TMR1 => ['TMR1H', 'TMR1L'],
-        TMR2 => 'TMR2',
+        TMR0 => { reg => 'TMR0', freg => 'INTCON', flag => 'T0IF', enable => 'T0IE', ereg => 'INTCON' },
+        TMR1 => { reg => ['TMR1H', 'TMR1L'], freg => 'PIR1', ereg => 'PIE1', flag => 'TMR1IF', enable => 'TMR1IE' },
+        TMR2 => { reg => 'TMR2', freg => 'PIR1', flag => 'TMR2IF', ereg => 'PIE1', enable => 'TMR2IF' },
         # timer 0 clock input
         T0CKI => 3,
         # timer 1 clock input
@@ -263,10 +263,18 @@ has eint_pins => (is => 'ro', default => sub {
 
 has ioc_pins => (is => 'ro', default => sub {
     {
-        RB4 => 10,
-        RB5 => 11,
-        RB6 => 12,
-        RB7 => 13,
+        ## there is no special IOC register, so use nothing
+        RB4 => [10],
+        RB5 => [11],
+        RB6 => [12],
+        RB7 => [13],
+    }
+});
+
+has ioc_ports => (is => 'ro', default => sub {
+    {
+        FLAG => 'RBIF',
+        ENABLE => 'RBIE',
     }
 });
 
@@ -276,6 +284,9 @@ has usart_pins => (is => 'ro', default => sub {
         async_out => 'TX',
         sync_clock => 'CK',
         sync_data => 'DT',
+        #TODO
+        rx_int => {},
+        tx_int => {},
         # this defines the port names that the user can use
         # validly. The port names define whether the user wants to use them in
         # synchronous or asynchronous mode
