@@ -1,7 +1,7 @@
 package VIC::PIC::P16F687;
 use strict;
 use warnings;
-our $VERSION = '0.24';
+our $VERSION = '0.25';
 $VERSION = eval $VERSION;
 use Moo;
 extends 'VIC::PIC::Base';
@@ -324,16 +324,26 @@ has eint_pins => (is => 'ro', default => sub {
 
 has ioc_pins => (is => 'ro', default => sub {
     {
-        RA0 => 19,
-        RA1 => 18,
-        RA2 => 17,
-        RA3 => 4,
-        RA4 => 3,
-        RA5 => 2,
-        RB4 => 13,
-        RB5 => 12,
-        RB6 => 11,
-        RB7 => 10,
+              #pin, #ioc-bit #ioc-reg
+        RA0 => [19, 'IOCA0', 'IOCA'],
+        RA1 => [18, 'IOCA1', 'IOCA'],
+        RA2 => [17, 'IOCA2', 'IOCA'],
+        RA3 => [4,  'IOCA3', 'IOCA'],
+        RA4 => [3,  'IOCA4', 'IOCA'],
+        RA5 => [2,  'IOCA5', 'IOCA'],
+        RB4 => [13, 'IOCB4', 'IOCB'], 
+        RB5 => [12, 'IOCB5', 'IOCB'],
+        RB6 => [11, 'IOCB6', 'IOCB'],
+        RB7 => [10, 'IOCB7', 'IOCB'],
+    }
+});
+
+has ioc_ports => (is => 'ro', default => sub {
+    {
+        PORTA => 'IOCA',
+        PORTB => 'IOCB',
+        FLAG => 'RABIF',
+        ENABLE => 'RABIE',
     }
 });
 
@@ -343,6 +353,9 @@ has usart_pins => (is => 'ro', default => sub {
         async_out => 'TX',
         sync_clock => 'CK',
         sync_data => 'DT',
+        #TODO
+        rx_int => {},
+        tx_int => {},
         # this defines the port names that the user can use
         # validly. The port names define whether the user wants to use them in
         # synchronous or asynchronous mode
